'use client'
import { useRouter } from 'next/navigation';
import { getSession } from 'next-auth/react';
import { useEffect, useState } from 'react';
import useConfigChatStore from '@/feature/messenger/store/chat_store/useConfigChatStore';
import Loading from '../../loading';
import toast from 'react-hot-toast';
import { closeSession, setTypeSession } from '@/feature/messenger/utils/CloseSession';
import { validatePingBack } from '@/src/services/auth/AuthServices';
import { useTranslation } from '@/src/hooks/useTranslation';


const Select = () => {

    const { changeLanguage } = useTranslation();
    const configChatActions = useConfigChatStore(state => state.actions);
    const [listChat, setListChat] = useState([]);
    const [selected, setSelected] = useState(null);
    const route = useRouter();
    

    const handleSetTypeLogin = (sesionData: any) => {
        const typeLogin = sesionData?.user?.typeLogin;
        setTypeSession(typeLogin);
    }
    const validateAuthenticationBack = async () => {   
        const validate = await validatePingBack();      
        if (validate.status == 401) {
            closeSession();
        }
        const sesionData = await getSession();
        const language = sesionData?.user?.language;
        const chatbots = sesionData?.user?.chatbots;
        //changeLanguage(language || 'es');
        if (chatbots == undefined || chatbots == null) {
            route.push('/messenger');
        }            
        if (chatbots != undefined) {
            handleSetTypeLogin(sesionData);
            if (chatbots.length == 1) {
                configChatActions.initChatService(chatbots[0].id_chatbot);
                route.push('/messenger');
            }
            setListChat(chatbots);   
        }
        if (chatbots.length == 0) {
            closeSession();
        }
        
    }
    useEffect(() => {
        validateAuthenticationBack();
    }, [])

    const handleSelect = (event: any) => {
        setSelected(event.target.value);
    }

    const handleClick = () => {
        if (selected == null || selected == 0 || selected == '') {
            toast.error("Por favor seleccione un chat");
            return;
        }
        configChatActions.initChatService(selected);
        route.push('/messenger');
    }

    const Logout = () => {
        closeSession();
    }

    return (
        <>
            {listChat.length > 1 ? (
                    <div className="w-screen h-screen flex flex-col justify-center items-center">
                        <div>
                            <div className="w-full max-w-sm p-4 bg-white border border-gray-200 rounded-lg shadow sm:p-6 md:p-8 dark:bg-gray-800 dark:border-gray-700">
                                <div className="space-y-6" >
                                    <h5 className="text-xl font-medium text-gray-900 dark:text-white">Bienvenido a Multiagente como usted tiene muchos chat activos seleccione uno para comenzar</h5>
                                    <div className="mx-auto w-80">
                                        <label htmlFor="countries" className="block mb-2 text-sm font-medium text-gray-900 dark:text-white">Seleccione un chat</label>
                                        <select onChange={handleSelect} id="countries" className="bg-gray-50 border border-gray-300 text-gray-900 text-sm rounded-lg focus:ring-blue-500 focus:border-blue-500 block w-full p-2.5 dark:bg-gray-700 dark:border-gray-600 dark:placeholder-gray-400 dark:text-white dark:focus:ring-blue-500 dark:focus:border-blue-500">
                                            <option defaultValue=""> Selecciona </option>
                                            {listChat.map((chat: any) => (
                                                <option key={chat.id_chatbot} value={chat.id_chatbot}>{chat.name}</option>
                                            ))}
                                        </select>
                                    </div>
                                    <button onClick={handleClick} type="button" className="w-full text-white bg-blue-700 hover:bg-blue-800 focus:ring-4 focus:outline-none focus:ring-blue-300 font-medium rounded-lg text-sm px-5 py-2.5 text-center dark:bg-blue-600 dark:hover:bg-blue-700 dark:focus:ring-blue-800">¡Iniciar Ahora!</button>
                                    <div className="text-sm font-medium text-gray-500 dark:text-gray-300">
                                        Deseas cerrar sesión? <a href="#" className="text-blue-700 hover:underline dark:text-blue-500" onClick={Logout}>Salir</a>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </div>
                ) : (
                    <Loading />
                )
            }
        </>
    )
}

export default Select